@@ -145,6 +145,7 @@ from .._impl import (
     scout_compute_api_ExponentialResultDetails as ExponentialResultDetails,
     scout_compute_api_Fft as Fft,
     scout_compute_api_FftWindow as FftWindow,
+    scout_compute_api_FilterByExpressionSeries as FilterByExpressionSeries,
     scout_compute_api_FirstPointMatchingCondition as FirstPointMatchingCondition,
     scout_compute_api_ForwardFillInterpolation as ForwardFillInterpolation,
     scout_compute_api_ForwardFillResampleInterpolationConfiguration as ForwardFillResampleInterpolationConfiguration,
@@ -247,6 +248,7 @@ from .._impl import (
     scout_compute_api_OutputFormat as OutputFormat,
     scout_compute_api_OutputRangeStart as OutputRangeStart,
     scout_compute_api_OutputRangeStartVisitor as OutputRangeStartVisitor,
+    scout_compute_api_PaddedRanges as PaddedRanges,
     scout_compute_api_PageInfo as PageInfo,
     scout_compute_api_PageStrategy as PageStrategy,
     scout_compute_api_PageStrategyVisitor as PageStrategyVisitor,
@@ -278,6 +280,7 @@ from .._impl import (
     scout_compute_api_RangeAggregationOperation as RangeAggregationOperation,
     scout_compute_api_RangeAggregationOperationVisitor as RangeAggregationOperationVisitor,
     scout_compute_api_RangeMap as RangeMap,
+    scout_compute_api_RangePaddingConfiguration as RangePaddingConfiguration,
     scout_compute_api_RangeSeries as RangeSeries,
     scout_compute_api_RangeSeriesVisitor as RangeSeriesVisitor,
     scout_compute_api_RangeSummary as RangeSummary,
@@ -297,6 +300,7 @@ from .._impl import (
     scout_compute_api_ScatterFitOptions as ScatterFitOptions,
     scout_compute_api_ScatterSummarizationStrategy as ScatterSummarizationStrategy,
     scout_compute_api_ScatterSummarizationStrategyVisitor as ScatterSummarizationStrategyVisitor,
+    scout_compute_api_ScatterTemporalAggregation as ScatterTemporalAggregation,
     scout_compute_api_SearchEventOriginType as SearchEventOriginType,
     scout_compute_api_SelectIndexFrom1dEnumArraySeries as SelectIndexFrom1dEnumArraySeries,
     scout_compute_api_SelectIndexFrom1dNumericArraySeries as SelectIndexFrom1dNumericArraySeries,
@@ -313,6 +317,7 @@ from .._impl import (
     scout_compute_api_SignalFilterConfiguration as SignalFilterConfiguration,
     scout_compute_api_SignalFilterConfigurationVisitor as SignalFilterConfigurationVisitor,
     scout_compute_api_SignalFilterSeries as SignalFilterSeries,
+    scout_compute_api_SinglePoint as SinglePoint,
     scout_compute_api_SpatialDecimateStrategy as SpatialDecimateStrategy,
     scout_compute_api_StabilityDetectionRanges as StabilityDetectionRanges,
     scout_compute_api_StabilityWindowConfiguration as StabilityWindowConfiguration,
@@ -337,6 +342,7 @@ from .._impl import (
     scout_compute_api_TagFilterValidationErrorType as TagFilterValidationErrorType,
     scout_compute_api_TagFilters as TagFilters,
     scout_compute_api_TagFiltersVisitor as TagFiltersVisitor,
+    scout_compute_api_TemporalDecimateStrategy as TemporalDecimateStrategy,
     scout_compute_api_Threshold as Threshold,
     scout_compute_api_ThresholdOperator as ThresholdOperator,
     scout_compute_api_ThresholdVisitor as ThresholdVisitor,
@@ -359,8 +365,11 @@ from .._impl import (
     scout_compute_api_UnitResult as UnitResult,
     scout_compute_api_UnitResultVisitor as UnitResultVisitor,
     scout_compute_api_UnitsMissing as UnitsMissing,
+    scout_compute_api_Value as Value,
     scout_compute_api_ValueDifferenceSeries as ValueDifferenceSeries,
     scout_compute_api_ValueMapSeries as ValueMapSeries,
+    scout_compute_api_ValueStrategy as ValueStrategy,
+    scout_compute_api_ValueVisitor as ValueVisitor,
     scout_compute_api_VariableName as VariableName,
     scout_compute_api_VariableValue as VariableValue,
     scout_compute_api_VariableValueVisitor as VariableValueVisitor,
@@ -513,6 +522,7 @@ __all__ = [
     'ExponentialResultDetails',
     'Fft',
     'FftWindow',
+    'FilterByExpressionSeries',
     'FirstPointMatchingCondition',
     'ForwardFillInterpolation',
     'ForwardFillResampleInterpolationConfiguration',
@@ -615,6 +625,7 @@ __all__ = [
     'OutputFormat',
     'OutputRangeStart',
     'OutputRangeStartVisitor',
+    'PaddedRanges',
     'PageInfo',
     'PageStrategy',
     'PageStrategyVisitor',
@@ -646,6 +657,7 @@ __all__ = [
     'RangeAggregationOperation',
     'RangeAggregationOperationVisitor',
     'RangeMap',
+    'RangePaddingConfiguration',
     'RangeSeries',
     'RangeSeriesVisitor',
     'RangeSummary',
@@ -665,6 +677,7 @@ __all__ = [
     'ScatterFitOptions',
     'ScatterSummarizationStrategy',
     'ScatterSummarizationStrategyVisitor',
+    'ScatterTemporalAggregation',
     'SearchEventOriginType',
     'SelectIndexFrom1dEnumArraySeries',
     'SelectIndexFrom1dNumericArraySeries',
@@ -681,6 +694,7 @@ __all__ = [
     'SignalFilterConfiguration',
     'SignalFilterConfigurationVisitor',
     'SignalFilterSeries',
+    'SinglePoint',
     'SpatialDecimateStrategy',
     'StabilityDetectionRanges',
     'StabilityWindowConfiguration',
@@ -705,6 +719,7 @@ __all__ = [
     'TagFilterValidationErrorType',
     'TagFilters',
     'TagFiltersVisitor',
+    'TemporalDecimateStrategy',
     'Threshold',
     'ThresholdVisitor',
     'ThresholdOperator',
@@ -727,8 +742,11 @@ __all__ = [
     'UnitResult',
     'UnitResultVisitor',
     'UnitsMissing',
+    'Value',
+    'ValueVisitor',
     'ValueDifferenceSeries',
     'ValueMapSeries',
+    'ValueStrategy',
     'VariableName',
     'VariableValue',
     'VariableValueVisitor',
