@@ -11,7 +11,6 @@ from .._impl import (
     scout_compute_resolved_api_BandStopConfiguration as BandStopConfiguration,
     scout_compute_resolved_api_BinaryArithmeticSeriesNode as BinaryArithmeticSeriesNode,
     scout_compute_resolved_api_BitOperationSeriesNode as BitOperationSeriesNode,
-    scout_compute_resolved_api_CachedStorageLocator as CachedStorageLocator,
     scout_compute_resolved_api_Cartesian3dBounds as Cartesian3dBounds,
     scout_compute_resolved_api_Cartesian3dNode as Cartesian3dNode,
     scout_compute_resolved_api_Cartesian3dNodeVisitor as Cartesian3dNodeVisitor,
@@ -46,6 +45,7 @@ from .._impl import (
     scout_compute_resolved_api_ExponentialCurve as ExponentialCurve,
     scout_compute_resolved_api_ExtremaRangesNode as ExtremaRangesNode,
     scout_compute_resolved_api_FftNode as FftNode,
+    scout_compute_resolved_api_FilterByExpressionSeriesNode as FilterByExpressionSeriesNode,
     scout_compute_resolved_api_ForwardFillInterpolation as ForwardFillInterpolation,
     scout_compute_resolved_api_ForwardFillResampleInterpolationConfiguration as ForwardFillResampleInterpolationConfiguration,
     scout_compute_resolved_api_FrequencyDomainNode as FrequencyDomainNode,
@@ -95,6 +95,7 @@ from .._impl import (
     scout_compute_resolved_api_NumericUnionSeriesNode as NumericUnionSeriesNode,
     scout_compute_resolved_api_OffsetSeriesNode as OffsetSeriesNode,
     scout_compute_resolved_api_OnChangeRangesNode as OnChangeRangesNode,
+    scout_compute_resolved_api_PaddedRangesNode as PaddedRangesNode,
     scout_compute_resolved_api_PercentageThreshold as PercentageThreshold,
     scout_compute_resolved_api_PeriodogramNode as PeriodogramNode,
     scout_compute_resolved_api_PersistenceWindowConfiguration as PersistenceWindowConfiguration,
@@ -175,7 +176,6 @@ __all__ = [
     'BandStopConfiguration',
     'BinaryArithmeticSeriesNode',
     'BitOperationSeriesNode',
-    'CachedStorageLocator',
     'Cartesian3dBounds',
     'Cartesian3dNode',
     'Cartesian3dNodeVisitor',
@@ -210,6 +210,7 @@ __all__ = [
     'ExponentialCurve',
     'ExtremaRangesNode',
     'FftNode',
+    'FilterByExpressionSeriesNode',
     'ForwardFillInterpolation',
     'ForwardFillResampleInterpolationConfiguration',
     'FrequencyDomainNode',
@@ -259,6 +260,7 @@ __all__ = [
     'NumericUnionSeriesNode',
     'OffsetSeriesNode',
     'OnChangeRangesNode',
+    'PaddedRangesNode',
     'PercentageThreshold',
     'PeriodogramNode',
     'PersistenceWindowConfiguration',
