@@ -1,5 +1,7 @@
 # coding=utf-8
 from .._impl import (
+    security_api_workspace_PreferredRefNameConfiguration as PreferredRefNameConfiguration,
+    security_api_workspace_PreferredRefNameConfigurationVisitor as PreferredRefNameConfigurationVisitor,
     security_api_workspace_RemoveType as RemoveType,
     security_api_workspace_UpdateOrRemoveWorkspaceDisplayName as UpdateOrRemoveWorkspaceDisplayName,
     security_api_workspace_UpdateOrRemoveWorkspaceDisplayNameVisitor as UpdateOrRemoveWorkspaceDisplayNameVisitor,
@@ -8,11 +10,14 @@ from .._impl import (
     security_api_workspace_UpdateWorkspaceRequest as UpdateWorkspaceRequest,
     security_api_workspace_Workspace as Workspace,
     security_api_workspace_WorkspaceService as WorkspaceService,
+    security_api_workspace_WorkspaceSettings as WorkspaceSettings,
     security_api_workspace_WorkspaceSymbol as WorkspaceSymbol,
     security_api_workspace_WorkspaceSymbolVisitor as WorkspaceSymbolVisitor,
 )
 
 __all__ = [
+    'PreferredRefNameConfiguration',
+    'PreferredRefNameConfigurationVisitor',
     'RemoveType',
     'UpdateOrRemoveWorkspaceDisplayName',
     'UpdateOrRemoveWorkspaceDisplayNameVisitor',
@@ -20,6 +25,7 @@ __all__ = [
     'UpdateOrRemoveWorkspaceSymbolVisitor',
     'UpdateWorkspaceRequest',
     'Workspace',
+    'WorkspaceSettings',
     'WorkspaceSymbol',
     'WorkspaceSymbolVisitor',
     'WorkspaceService',
